@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-import vapoursynth as vs
-from jetpytools import normalize_seq
+from jetpytools import clamp, normalize_seq
 
 from ..enums import ColorRange, ColorRangeLike
 from ..types import HoldsVideoFormat, VideoFormatLike
+from ..vs_proxy import vs
 from .info import get_depth, get_video_format
 
 __all__ = [
@@ -21,7 +21,7 @@ __all__ = [
 
 
 def scale_value(
-    value: int | float,
+    value: float,
     input_depth: int | VideoFormatLike | HoldsVideoFormat,
     output_depth: int | VideoFormatLike | HoldsVideoFormat,
     range_in: ColorRangeLike | None = None,
@@ -29,7 +29,7 @@ def scale_value(
     scale_offsets: bool = True,
     chroma: bool = False,
     family: vs.ColorFamily | None = None,
-) -> int | float:
+) -> float:
     """
     Converts the value to the specified bit depth, or bit depth of the clip/format specified.
 
@@ -55,7 +55,7 @@ def scale_value(
 
     if range_in is None:
         if isinstance(input_depth, vs.VideoNode):
-            range_in = ColorRange(input_depth)
+            range_in = ColorRange.from_video(input_depth, func=scale_value)
         elif vs.RGB in (in_fmt.color_family, family):
             range_in = ColorRange.FULL
         else:
@@ -65,7 +65,7 @@ def scale_value(
 
     if range_out is None:
         if isinstance(output_depth, vs.VideoNode):
-            range_out = ColorRange(output_depth)
+            range_out = ColorRange.from_video(output_depth, func=scale_value)
         elif vs.RGB in (out_fmt.color_family, family):
             range_out = ColorRange.FULL
         else:
@@ -99,16 +99,16 @@ def scale_value(
             out_value += 16 << (out_fmt.bits_per_sample - 8)
 
     if out_fmt.sample_type is vs.INTEGER:
-        out_value = max(min(round(out_value), get_peak_value(out_fmt, range_in=ColorRange.FULL)), 0)
+        out_value = clamp(round(out_value), 0, get_peak_value(out_fmt, range_in=ColorRange.FULL))
 
     return out_value
 
 
 def scale_mask(
-    value: int | float,
+    value: float,
     input_depth: int | VideoFormatLike | HoldsVideoFormat,
     output_depth: int | VideoFormatLike | HoldsVideoFormat,
-) -> int | float:
+) -> float:
     """
     Converts the value to the specified bit depth, or bit depth of the clip/format specified.
     Intended for mask clips which are always full range.
@@ -126,12 +126,12 @@ def scale_mask(
 
 
 def scale_delta(
-    value: int | float,
+    value: float,
     input_depth: int | VideoFormatLike | HoldsVideoFormat,
     output_depth: int | VideoFormatLike | HoldsVideoFormat,
     range_in: ColorRangeLike | None = None,
     range_out: ColorRangeLike | None = None,
-) -> int | float:
+) -> float:
     """
     Converts the value to the specified bit depth, or bit depth of the clip/format specified.
     Uses the clip's range (if only one clip is passed) for both depths.
@@ -196,7 +196,7 @@ def get_lowest_value(
         else:
             range_in = ColorRange.LIMITED
 
-    if ColorRange(range_in).is_limited:
+    if ColorRange.from_param(range_in, get_lowest_value).is_limited:
         return 16 << get_depth(fmt) - 8
 
     return 0
@@ -287,7 +287,7 @@ def get_peak_value(
         else:
             range_in = ColorRange.LIMITED
 
-    if ColorRange(range_in).is_limited:
+    if ColorRange.from_param(range_in, get_peak_value).is_limited:
         return (240 if chroma else 235) << get_depth(fmt) - 8
 
     return (1 << get_depth(fmt)) - 1
